/* See LICENSE file for copyright and license details. */

/* appearance */
static const unsigned int borderpx  = 2;        /* border pixel of windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const int showbar       = 1;     /* 0 means no bar */
static const int topbar        = 1;     /* 0 means bottom bar */
static const char *fonts[]     = { "FiraCode Nerd Font:style=Medium:dpi=192:antialias=true:pixelsize=44" };
static const char col_gray1[]  = "#222222";
static const char col_gray2[]  = "#444444";
static const char col_gray3[]  = "#bbbbbb";
static const char col_gray4[]  = "#eeeeee";
static const char col_acc[]    = "#ff0000";
static const char *colors[][3] = {
	/*                   fg         bg         border   */
	[SchemeNorm]     = { col_gray3, col_gray1, col_gray2 },
	[SchemeSel]      = { col_gray4, col_acc,   col_acc   },
	[SchemeStatus]   = { col_gray3, col_gray1, "#000000" }, // Statusbar right {text,background,not used but cannot be empty}
	[SchemeTagsSel]  = { col_gray4, col_acc,   "#000000" }, // Tagbar left selected {text,background,not used but cannot be empty}
    [SchemeTagsNorm] = { col_gray3, col_gray1, "#000000" }, // Tagbar left unselected {text,background,not used but cannot be empty}
    [SchemeInfoSel]  = { col_gray3, col_gray1, "#000000" }, // infobar middle  selected {text,background,not used but cannot be empty}
    [SchemeInfoNorm] = { col_gray3, col_gray1, "#000000" }, // infobar middle  unselected {text,background,not used but cannot be empty}
};

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title                 tags mask     isfloating   monitor */
    {"firefox",   "Toolkit",  "Picture-in-Picture", -1,           1,           -1},
};

/* layout(s) */
static const float mfact     = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster     = 1;    /* number of clients in master area */
static const int resizehints = 1;    /* 1 means respect size hints in tiled resizals */
static const int lockfullscreen = 1; /* 1 will force focus on the fullscreen window */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "[]=",      tile },    /* first entry is default */
	{ "><>",      NULL },    /* no layout function means floating behavior */
	{ "[M]",      monocle },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      comboview,      {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      combotag,       {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static const char *runcmd[]         = { "dmenu_run", NULL };
static const char *termcmd[]        = { "kitty", "-1", NULL };
static const char *browsercmd[]     = { "mullvad-browser", NULL };
static const char *lockcmd[]        = { "loginctl", "lock-session", NULL };
static const char *passwdcmd[]      = { "keepassxc", NULL };
static const char *mailcmd[]        = { "thunderbird", NULL };
static const char *volupcmd[]       = { "pamixer", "-i", "1", NULL };
static const char *bigvolupcmd[]    = { "pamixer", "-i", "5", NULL };
static const char *voldowncmd[]     = { "pamixer", "-d", "1", NULL };
static const char *bigvoldowncmd[]  = { "pamixer", "-d", "5", NULL };
static const char *volmutecmd[]     = { "pamixer", "-t", NULL };
static const char *selectsoundcmd[] = { "select-sound-output.sh", NULL };
static const char *screenshotcmd[]  = { "screenshot.sh", NULL };
static const char *notifyctxcmd[]   = { "dunstctl", "context", NULL };
static const char *closenotifycmd[] = { "dunstctl", "close", NULL };
static const char *lastnotifycmd[]  = { "dunstctl", "history-pop", NULL };

static Key keys[] = {
	/* modifier                     key        function           argument */
	{ MODKEY,                       XK_p,      spawn,             {.v = runcmd } },
	{ MODKEY|ShiftMask,             XK_Return, spawn,             {.v = termcmd } },
	{ MODKEY|ShiftMask,             XK_b,      spawn,             {.v = browsercmd } },
	{ MODKEY|ShiftMask,             XK_o,      spawn,             {.v = lockcmd } },
	{ MODKEY|ShiftMask,             XK_p,      spawn,             {.v = passwdcmd } },
	{ MODKEY|ShiftMask,             XK_n,      spawn,             {.v = selectsoundcmd } },
	{ MODKEY|ShiftMask,             XK_m,      spawn,             {.v = mailcmd } },
	{ MODKEY|ShiftMask,             XK_s,      spawn,             {.v = screenshotcmd } },
	{ MODKEY,						XK_u,      spawn,			  {.v = closenotifycmd } },
	{ MODKEY|ShiftMask,				XK_u,      spawn,			  {.v = lastnotifycmd } },
	{ MODKEY|ControlMask,	     	XK_u,      spawn,			  {.v = notifyctxcmd } },
    { 0,         XF86XK_AudioRaiseVolume,      spawn,             {.v = volupcmd } },
    { ShiftMask, XF86XK_AudioRaiseVolume,      spawn,             {.v = bigvolupcmd } },
    { 0,         XF86XK_AudioLowerVolume,      spawn,             {.v = voldowncmd } },
    { ShiftMask, XF86XK_AudioLowerVolume,      spawn,             {.v = bigvoldowncmd } },
    { 0,         XF86XK_AudioMute,             spawn,             {.v = volmutecmd } },
    { MODKEY|ShiftMask,             XK_r,      restart,           {0} },
	{ MODKEY,                       XK_b,      togglebar,         {0} },
	{ MODKEY,                       XK_j,      focusstack,        {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,        {.i = -1 } },
	{ MODKEY,                       XK_i,      incnmaster,        {.i = +1 } },
	{ MODKEY,                       XK_d,      incnmaster,        {.i = -1 } },
	{ MODKEY,                       XK_h,      setmfact,          {.f = -0.05} },
	{ MODKEY,                       XK_l,      setmfact,          {.f = +0.05} },
	{ MODKEY|ShiftMask,             XK_h,      setcfact,          {.f = +0.25} },
	{ MODKEY|ShiftMask,             XK_l,      setcfact,          {.f = -0.25} },
	{ MODKEY|ShiftMask,             XK_a,      setcfact,          {.f =  0.00} },
	{ MODKEY,                       XK_Return, zoom,              {0} },
	{ MODKEY,                       XK_Tab,    view,              {0} },
	{ MODKEY,                       XK_x,      killclient,        {0} },
	{ MODKEY,                       XK_t,      setlayout,         {.v = &layouts[0]} },
	{ MODKEY,                       XK_f,      setlayout,         {.v = &layouts[1]} },
	{ MODKEY,                       XK_m,      setlayout,         {.v = &layouts[2]} },
	{ MODKEY,                       XK_space,  setlayout,         {0} },
	{ MODKEY|ShiftMask,             XK_space,  togglefloating,    {0} },
	{ MODKEY|ShiftMask,             XK_t,      togglealwaysontop, {0} },
	{ MODKEY,                       XK_0,      view,              {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,      tag,               {.ui = ~0 } },
	{ MODKEY,                       XK_comma,  focusmon,          {.i = -1 } },
	{ MODKEY,                       XK_period, focusmon,          {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,  tagmon,            {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_period, tagmon,            {.i = +1 } },
	TAGKEYS(                        XK_1,                         0)
	TAGKEYS(                        XK_2,                         1)
	TAGKEYS(                        XK_3,                         2)
	TAGKEYS(                        XK_4,                         3)
	TAGKEYS(                        XK_5,                         4)
	TAGKEYS(                        XK_6,                         5)
	TAGKEYS(                        XK_7,                         6)
	TAGKEYS(                        XK_8,                         7)
	TAGKEYS(                        XK_9,                         8)
	{ MODKEY|ShiftMask,             XK_q,      quit,              {0} },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

static const char *ipcsockpath = "/tmp/dwm.sock";
static IPCCommand ipccommands[] = {
	IPCCOMMAND(view,                1,      {ARG_TYPE_UINT}),
	IPCCOMMAND(toggleview,          1,      {ARG_TYPE_UINT}),
	IPCCOMMAND(tag,                 1,      {ARG_TYPE_UINT}),
	IPCCOMMAND(toggletag,           1,      {ARG_TYPE_UINT}),
	IPCCOMMAND(tagmon,              1,      {ARG_TYPE_UINT}),
	IPCCOMMAND(focusmon,            1,      {ARG_TYPE_SINT}),
	IPCCOMMAND(focusstack,          1,      {ARG_TYPE_SINT}),
	IPCCOMMAND(zoom,                1,      {ARG_TYPE_NONE}),
	IPCCOMMAND(incnmaster,          1,      {ARG_TYPE_SINT}),
	IPCCOMMAND(killclient,          1,      {ARG_TYPE_SINT}),
	IPCCOMMAND(togglefloating,      1,      {ARG_TYPE_NONE}),
	IPCCOMMAND(setmfact,            1,      {ARG_TYPE_FLOAT}),
	IPCCOMMAND(setlayoutsafe,       1,      {ARG_TYPE_PTR}),
	IPCCOMMAND(quit,                1,      {ARG_TYPE_NONE})
};
